using System;
using System.Runtime.InteropServices;
using System.Web.UI;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Serialization;

using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.WebPartPages;
using System.Web.UI.WebControls;
using System.Xml.Xsl;
using System.Xml;
using System.IO;
using System.Collections.Generic;
using System.Net;
using System.Security.Permissions;
using System.Security;

namespace DevLeap.MOSS2007.ParseXML
{
    [Guid("e8229a98-c480-48cc-b69c-2dcb5e38d5ff")]
    public class DynamicContentWebPart : System.Web.UI.WebControls.WebParts.WebPart, IWebEditable
    {
        public DynamicContentWebPart()
        {
            this.ExportMode = WebPartExportMode.All;
        }

        private String _xmlContentUri;

        [WebBrowsable()]
        [Personalizable()]
        public String XmlContentUri
        {
            get { return _xmlContentUri; }
            set { _xmlContentUri = value; }
        }

        private String _xsltTemplate;

        [WebBrowsable()]
        [Personalizable()]
        public String XsltTemplate
        {
            get { return _xsltTemplate; }
            set { _xsltTemplate = value; }
        }

        private PlaceHolder _outputHtml;

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            this._outputHtml = new PlaceHolder();
            this.Controls.Add(this._outputHtml);
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            EnsureChildControls();

            if ((!String.IsNullOrEmpty(this.XmlContentUri)) && (!String.IsNullOrEmpty(this.XsltTemplate)))
            {
                XslCompiledTransform xslt = new XslCompiledTransform();
                xslt.Load(new XmlTextReader(new StringReader(this.XsltTemplate)));

                XmlDocument xml = new XmlDocument();
                xml.Load(this.XmlContentUri);

                StringWriter sw = new StringWriter();
                xslt.Transform(xml, null, sw);

                String controls = sw.ToString();

                this.Controls.Add(this.Page.ParseControl(controls));
            }
            else
            {
                this.Controls.Add(new LiteralControl("Please configure WebPart..."));
            }
        }

        protected override bool OnBubbleEvent(object source, EventArgs args)
        {
            return base.OnBubbleEvent(source, args);
        }

        #region IWebEditable Members

        EditorPartCollection IWebEditable.CreateEditorParts()
        {
            List<EditorPart> editors = new List<EditorPart>();
            DynamicContentEditorPart editor = new DynamicContentEditorPart();
            editor.ID = this.ID + "_DynamicContentWebPart";
            editor.Title = "Editor of DynamicContentWebPart";
            editors.Add(editor);
            return new EditorPartCollection(editors);
        }

        object IWebEditable.WebBrowsableObject
        {
            get { return(this); }
        }

        #endregion
    }

    public class DynamicContentEditorPart : EditorPart
    {
        private TextBox XmlContentUri;
        private TextBox XsltContent;

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            this.XmlContentUri = new TextBox();
            this.Controls.Add(new LiteralControl("XML URI:<br>"));
            this.Controls.Add(XmlContentUri);

            this.XsltContent = new TextBox();
            this.XsltContent.TextMode = TextBoxMode.MultiLine;
            this.XsltContent.Rows = 10;
            this.Controls.Add(new LiteralControl("<br>XSLT:<br>"));
            this.Controls.Add(XsltContent);
        }

        public override bool ApplyChanges()
        {
            EnsureChildControls();
            DynamicContentWebPart wp = WebPartToEdit as DynamicContentWebPart;
            if (wp != null)
            {
                wp.XmlContentUri = this.XmlContentUri.Text;
                wp.XsltTemplate = this.XsltContent.Text;
                return true;
            }
            else
            {
                return false;
            }
        }

        public override void SyncChanges()
        {
            EnsureChildControls();
            DynamicContentWebPart wp = WebPartToEdit as DynamicContentWebPart;
            if (wp != null)
            {
                this.XmlContentUri.Text = wp.XmlContentUri;
                this.XsltContent.Text = wp.XsltTemplate;
            }
        }
    }
}
