using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.SharePoint;
using System.Text.RegularExpressions;

namespace DevLeap.MOSS2007.RegExField
{
    public class RegExTextField : Microsoft.SharePoint.SPFieldText
    {
        public RegExTextField(SPFieldCollection fields, String fieldName)
            : base(fields, fieldName)
        {
            this.Init();
        }

        public RegExTextField(SPFieldCollection fields, String typeName, String displayName)
            : base(fields, typeName, displayName)
        {
            this.Init();
        }

        private void Init()
        {
            Object regularExpressionValue = GetCustomProperty("RegularExpression");
            if (regularExpressionValue != null)
                this.RegularExpression = regularExpressionValue.ToString();
            else
                this.RegularExpression = String.Empty;

            Object errorMessageValue = GetCustomProperty("ErrorMessage");
            if (errorMessageValue != null)
                this.ErrorMessage = errorMessageValue.ToString();
            else
                this.ErrorMessage = String.Empty;
        }

        private String _regularExpression;

        public String RegularExpression
        {
            get { return (this._regularExpression); }
            set { this._regularExpression = value; }
        }

        private String _errorMessage;

        public String ErrorMessage
        {
            get { return (this._errorMessage); }
            set { this._errorMessage = value; }
        }

        public override string GetValidatedString(Object value)
        {
            if (value == null)
                return String.Empty;

            String textValue = value.ToString();

            Regex regex = new Regex(this.RegularExpression, RegexOptions.IgnoreCase);

            if (!regex.IsMatch(textValue))
            {
                throw new SPFieldValidationException(this.ErrorMessage);
            }
            else
            {
                return textValue;
            }
        }
    }
}
