using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using Microsoft.Office.Server.Search.Query;
using Microsoft.Office.Server;
using Microsoft.SharePoint;
using System.Data;

namespace DevLeap.MOSS2007.SearchDemo
{
    class Program
    {
        static void Main(String[] args)
        {
            SearchViaSoapWithSTRING();
            SearchViaSoapWithMSSQLFT();
            SearchViaObjectModelKeywordQuery();
            SearchViaObjectModelFullTextSqlQuery();
        }

        private static void SearchViaSoapWithSTRING()
        {
            Console.WriteLine("******************************************************");
            Console.WriteLine("KEYWORD Query via SOAP");
            Console.WriteLine("******************************************************");
            Console.WriteLine("Write text to search:\n");
            String textToSearch = Console.ReadLine();

            MOSS2007.Services.Search.QueryService ws =
                new MOSS2007.Services.Search.QueryService();

            ws.Url = "http://moss2007dev:9501/_vti_bin/search.asmx";
            ws.Credentials = System.Net.CredentialCache.DefaultCredentials;

            XmlDocument queryXml = new XmlDocument();
            queryXml.Load(@"..\..\QueryPacket.xml");

            XmlNamespaceManager ns = new XmlNamespaceManager(queryXml.NameTable);
            ns.AddNamespace("q", "urn:Microsoft.Search.Query");

            XmlNode queryTextNode = queryXml.SelectSingleNode("//q:QueryText", ns);
            ((XmlAttribute)queryTextNode.SelectSingleNode("@type")).Value = "STRING";
            ((XmlElement)queryTextNode).InnerText = textToSearch;

            String xmlResult = ws.Query(queryXml.OuterXml);
            Console.WriteLine(xmlResult);
        }

        private static void SearchViaSoapWithMSSQLFT()
        {
            Console.WriteLine("******************************************************");
            Console.WriteLine("SQL Query via SOAP");
            Console.WriteLine("******************************************************");

            Console.WriteLine("Write text to search:\n");
            String textToSearch = Console.ReadLine();

            MOSS2007.Services.Search.QueryService ws =
                new MOSS2007.Services.Search.QueryService();

            ws.Url = "http://moss2007dev:9501/_vti_bin/search.asmx";
            ws.Credentials = System.Net.CredentialCache.DefaultCredentials;

            XmlDocument queryXml = new XmlDocument();
            queryXml.Load(@"..\..\QueryPacket.xml");

            XmlNamespaceManager ns = new XmlNamespaceManager(queryXml.NameTable);
            ns.AddNamespace("q", "urn:Microsoft.Search.Query");

            XmlNode queryTextNode = queryXml.SelectSingleNode("//q:QueryText", ns);
            ((XmlAttribute)queryTextNode.SelectSingleNode("@type")).Value = "MSSQLFT";
            ((XmlElement)queryTextNode).InnerText = String.Format("SELECT Title, Path, Description FROM Scope() WHERE FREETEXT('{0}')", textToSearch);

            String xmlResult = ws.Query(queryXml.OuterXml);
            Console.WriteLine(xmlResult);
        }

        static void SearchViaObjectModelKeywordQuery()
        {
            Console.WriteLine("******************************************************");
            Console.WriteLine("KEYWORD Query via Object Model");
            Console.WriteLine("******************************************************");

            Console.WriteLine("Write text to search:\n");
            String textToSearch = Console.ReadLine();

            ServerContext context = ServerContext.GetContext(new SPSite("http://moss2007dev:9501/"));
            KeywordQuery keywordQuery = new KeywordQuery(context);
            keywordQuery.ResultTypes = ResultType.RelevantResults;
            keywordQuery.QueryText = textToSearch;

            ResultTableCollection result = keywordQuery.Execute();
            Console.WriteLine("Risultati: {0}", result.Count);

            if (result.Count > 0)
            {
                ResultTable relevantResults = result[ResultType.RelevantResults];
                DataTable resultsDataTable = new DataTable();
                resultsDataTable.Load(relevantResults, LoadOption.OverwriteChanges);

                foreach (DataRow row in resultsDataTable.Rows)
                {
                    Console.WriteLine(row["Title"]);
                }
            }
        }

        static void SearchViaObjectModelFullTextSqlQuery()
        {
            Console.WriteLine("******************************************************");
            Console.WriteLine("SQL Query via Object Model");
            Console.WriteLine("******************************************************");

            Console.WriteLine("Write text to search:\n");
            String textToSearch = Console.ReadLine();

            ServerContext context = ServerContext.GetContext(new SPSite("http://moss2007dev:9501/"));
            FullTextSqlQuery sqlQuery = new FullTextSqlQuery(context);
            sqlQuery.ResultTypes = ResultType.RelevantResults;
            sqlQuery.QueryText = String.Format("SELECT Title, Path, Description FROM Scope() WHERE FREETEXT('{0}')", textToSearch);

            ResultTableCollection result = sqlQuery.Execute();
            Console.WriteLine("Risultati: {0}", result.Count);

            if (result.Count > 0)
            {
                ResultTable relevantResults = result[ResultType.RelevantResults];
                DataTable resultsDataTable = new DataTable();
                resultsDataTable.Load(relevantResults, LoadOption.OverwriteChanges);

                foreach (DataRow row in resultsDataTable.Rows)
                {
                    Console.WriteLine(row["Title"]);
                }
            }
        }
    }
}
