using System;
using System.Runtime.InteropServices;
using System.Web.UI;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Serialization;

using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.WebPartPages;
using System.Web.UI.WebControls;
using System.Collections.Generic;

namespace DevLeap.MOSS2007.WebPartWithEditor
{
    [Guid("3953f5ae-e351-4617-b232-eaad9c25ccd3")]
    public class WebPartWithEditor : System.Web.UI.WebControls.WebParts.WebPart, IWebEditable
    {
        public WebPartWithEditor()
        {
            this.ExportMode = WebPartExportMode.All;
        }

        private String _siteUrl = "";

        [WebBrowsable(true), Personalizable(true)]
        public String SiteUrl
        {
            get { return _siteUrl; }
            set { _siteUrl = value; }
        }

        private DataGrid listOfLists;

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            this.listOfLists = new DataGrid();
            this.Controls.Add(this.listOfLists);
        }

        public override WebPartVerbCollection Verbs
        {
            get
            {
                WebPartVerb verbCustom = new WebPartVerb("WebPartWithEditor_Custom",
                    serverSideClick);
                return new WebPartVerbCollection(base.Verbs, new WebPartVerb[] { verbCustom });
            }
        }

        public void serverSideClick(Object s, WebPartEventArgs e)
        {
            this.SiteUrl = String.Empty;
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            EnsureChildControls();

            if (!String.IsNullOrEmpty(this.SiteUrl))
            {
                SPSite site = new SPSite(this.SiteUrl);
                SPWeb web = site.OpenWeb();

                String[] dataSource = new String[web.Lists.Count];
                for (Int32 c = 0; c < web.Lists.Count; c++)
                {
                    dataSource[c] = web.Lists[c].Title;
                }

                this.listOfLists.DataSource = dataSource;
                this.listOfLists.DataBind();
            }
        }

        #region IWebEditable Members

        EditorPartCollection IWebEditable.CreateEditorParts()
        {
            List<EditorPart> editors = new List<EditorPart>();
            EditorOfWebPartWithEditor editor = new EditorOfWebPartWithEditor();
            editor.ID = this.ID + "_editorPartForSiteUrl";
            editor.Title = "Editor of WebPartWithEditor";
            editors.Add(editor);
            return new EditorPartCollection(editors);
        }

        object IWebEditable.WebBrowsableObject
        {
            get { return this; }
        }

        #endregion
    }

    public class EditorOfWebPartWithEditor : EditorPart
    {
        private TextBox SiteUrl;

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            this.Controls.Add(new LiteralControl("Site URL:<br>"));

            this.SiteUrl = new TextBox();
            this.Controls.Add(this.SiteUrl);
        }

        public override bool ApplyChanges()
        {
            EnsureChildControls();
            WebPartWithEditor wp = WebPartToEdit as WebPartWithEditor;
            if (wp != null)
            {
                wp.SiteUrl = this.SiteUrl.Text;
            }
            else
            {
                return false;
            }

            return true;
        }

        public override void SyncChanges()
        {
            EnsureChildControls();
            WebPartWithEditor wp = WebPartToEdit as WebPartWithEditor;
            if (wp != null)
            {
                this.SiteUrl.Text = wp.SiteUrl;
            }
        }
    }
}
