using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Collections;
using System.Drawing;
using System.Workflow.ComponentModel.Compiler;
using System.Workflow.ComponentModel.Serialization;
using System.Workflow.ComponentModel;
using System.Workflow.ComponentModel.Design;
using System.Workflow.Runtime;
using System.Workflow.Activities;
using System.Workflow.Activities.Rules;
using System.Xml.Serialization;
using System.Xml;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Workflow;
using Microsoft.SharePoint.WorkflowActions;
using Microsoft.Office.Workflow.Utility;
using System.IO;

namespace DevLeap.MOSS2007.Workflows.Offers
{
    public sealed partial class OfferApproval : SharePointSequentialWorkflowActivity
    {
        public OfferApproval()
        {
            InitializeComponent();
        }

        public Guid workflowId = default(System.Guid);
        public Microsoft.SharePoint.Workflow.SPWorkflowActivationProperties workflowProperties = new Microsoft.SharePoint.Workflow.SPWorkflowActivationProperties();

        public static DependencyProperty OfferApprovedProperty = System.Workflow.ComponentModel.DependencyProperty.Register("OfferApproved", typeof(Boolean), typeof(OfferApproval));

        [Description("States if the Offer has been approved")]
        [Category("Custom")]
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        public Boolean OfferApproved
        {
            get
            {
                return ((Boolean)(base.GetValue(OfferApproval.OfferApprovedProperty)));
            }
            set
            {
                base.SetValue(OfferApproval.OfferApprovedProperty, value);
            }
        }

        public static DependencyProperty WorkflowItemAfterPropertiesProperty = DependencyProperty.Register("WorkflowItemAfterProperties", typeof(System.Collections.Hashtable), typeof(DevLeap.MOSS2007.Workflows.Offers.OfferApproval));

        [DesignerSerializationVisibilityAttribute(DesignerSerializationVisibility.Visible)]
        [BrowsableAttribute(true)]
        [CategoryAttribute("Misc")]
        public Hashtable WorkflowItemAfterProperties
        {
            get
            {
                return ((System.Collections.Hashtable)(base.GetValue(DevLeap.MOSS2007.Workflows.Offers.OfferApproval.WorkflowItemAfterPropertiesProperty)));
            }
            set
            {
                base.SetValue(DevLeap.MOSS2007.Workflows.Offers.OfferApproval.WorkflowItemAfterPropertiesProperty, value);
            }
        }

        public static DependencyProperty WorkflowItemBeforePropertiesProperty = DependencyProperty.Register("WorkflowItemBeforeProperties", typeof(System.Collections.Hashtable), typeof(DevLeap.MOSS2007.Workflows.Offers.OfferApproval));

        [DesignerSerializationVisibilityAttribute(DesignerSerializationVisibility.Visible)]
        [BrowsableAttribute(true)]
        [CategoryAttribute("Misc")]
        public Hashtable WorkflowItemBeforeProperties
        {
            get
            {
                return ((System.Collections.Hashtable)(base.GetValue(DevLeap.MOSS2007.Workflows.Offers.OfferApproval.WorkflowItemBeforePropertiesProperty)));
            }
            set
            {
                base.SetValue(DevLeap.MOSS2007.Workflows.Offers.OfferApproval.WorkflowItemBeforePropertiesProperty, value);
            }
        }

        public static DependencyProperty InitProperty = System.Workflow.ComponentModel.DependencyProperty.Register("Init", typeof(InitiationData), typeof(OfferApproval));

        [Description("Initiation data configuration")]
        [Category("Custom")]
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        public InitiationData Init
        {
            get
            {
                return ((InitiationData)(base.GetValue(OfferApproval.InitProperty)));
            }
            set
            {
                base.SetValue(OfferApproval.InitProperty, value);
            }
        }

        private void onWorkflowActivated1_Invoked(object sender, ExternalDataEventArgs e)
        {
            XmlSerializer xs = new XmlSerializer(typeof(InitiationData));
            this.Init = xs.Deserialize(
                new XmlTextReader(
                    new StringReader(this.workflowProperties.InitiationData)))
                        as InitiationData;
        }

        private void onWorkflowItemChangedEvent_Invoked(object sender, ExternalDataEventArgs e)
        {
            if (this.workflowProperties.Item != null)
            {
                this.OfferApproved =
                    (this.workflowProperties.Item.ModerationInformation.Status == SPModerationStatusType.Approved);
            }
        }

        private void moveItem_ExecuteCode(object sender, EventArgs e)
        {
            try
            {
                Guid siteId = this.workflowProperties.SiteId;
                Guid webId = this.workflowProperties.WebId;
                Guid sourceListId = this.workflowProperties.ListId;
                Int32 sourceItemId = this.workflowProperties.ItemId;

                SPSecurity.RunWithElevatedPrivileges(delegate()
                {
                    using (SPSite site = new SPSite(siteId))
                    {
                        using (SPWeb web = site.OpenWeb(webId))
                        {

                            SPList sourceList = web.Lists[sourceListId];
                            SPListItem sourceItem = sourceList.GetItemById(sourceItemId);
                            SPList destinationList = web.Lists[new Guid(this.Init.DestiantionList)];

                            if (sourceItem.File != null)
                            {
                                String destinationUri = destinationList.RootFolder.ServerRelativeUrl + "/" + sourceItem.File.Name;
                                sourceItem.File.MoveTo(destinationUri, this.Init.Overwrite);

                                if (this.Init.AddProtocol)
                                {
                                    SPFile destinationFile = web.GetFile(destinationUri);
                                    destinationFile.Item["Protocol"] = Guid.NewGuid();
                                    destinationFile.Item.Update();
                                }
                            }
                        }
                    }
                });

            }
            catch (SPException)
            {
                // Dotrei preoccupari della gestione errori
                throw;
            }
        }
    }
}
